aboutsummaryrefslogtreecommitdiffstats
path: root/test/net/java
diff options
context:
space:
mode:
authorAlexander Pelov <a_pelov@java.net>2005-12-01 12:26:39 +0000
committerAlexander Pelov <a_pelov@java.net>2005-12-01 12:26:39 +0000
commit7b861b5cf5c7f3fc738e8b45b1d75362330235fd (patch)
tree55052669f9d5aa75bc92c740cc4e688694210adb /test/net/java
parent08618c6ab74990e32afd361e3e6f89eff25b67da (diff)
downloadjitsi-7b861b5cf5c7f3fc738e8b45b1d75362330235fd.zip
jitsi-7b861b5cf5c7f3fc738e8b45b1d75362330235fd.tar.gz
jitsi-7b861b5cf5c7f3fc738e8b45b1d75362330235fd.tar.bz2
ResourcesService renamed to FileAccessService.
Diffstat (limited to 'test/net/java')
-rw-r--r--test/net/java/sip/communicator/slick/fileaccess/FileAccessServiceLick.java (renamed from test/net/java/sip/communicator/slick/resources/ResourcesServicesLick.java)18
-rw-r--r--test/net/java/sip/communicator/slick/fileaccess/TestFileAccessService.java (renamed from test/net/java/sip/communicator/slick/resources/TestFileAccessService.java)12
-rw-r--r--test/net/java/sip/communicator/slick/fileaccess/fileaccess.slick.manifest.mf (renamed from test/net/java/sip/communicator/slick/resources/resources.slick.manifest.mf)12
-rw-r--r--test/net/java/sip/communicator/slick/history/history.slick.manifest.mf2
-rw-r--r--test/net/java/sip/communicator/slick/media/media.slick.manifest.mf3
5 files changed, 21 insertions, 26 deletions
diff --git a/test/net/java/sip/communicator/slick/resources/resources.slick.manifest.mf b/test/net/java/sip/communicator/slick/fileaccess/fileaccess.slick.manifest.mf
index 74b88dc..5d36ea4 100644
--- a/test/net/java/sip/communicator/slick/resources/resources.slick.manifest.mf
+++ b/test/net/java/sip/communicator/slick/fileaccess/fileaccess.slick.manifest.mf
@@ -1,11 +1,11 @@
-Bundle-Activator: net.java.sip.communicator.slick.resources.ResourcesServicesLick
-Bundle-Name: Resources Services Implementation Compatibility Kit
-Bundle-Description: A Service Implementation Compatibility Kit for the Resources Services
+Bundle-Activator: net.java.sip.communicator.slick.fileaccess.FileAccessServiceLick
+Bundle-Name: File Access Service Implementation Compatibility Kit
+Bundle-Description: A Service Implementation Compatibility Kit for the File Access Services
Bundle-Vendor: sip-communicator.org
Bundle-Version: 0.0.1
Import-Package: junit.framework,
- net.java.sip.communicator.slick.resources,
- net.java.sip.communicator.service.resources,
+ net.java.sip.communicator.slick.fileaccess,
+ net.java.sip.communicator.service.fileaccess,
net.java.sip.communicator.service.configuration,
org.osgi.framework,
org.w3c.dom,
@@ -16,4 +16,4 @@ Import-Package: junit.framework,
javax.xml.transform.dom,
javax.xml.transform.stream,
org.apache.xml.serializer,
-Export-Package: net.java.sip.communicator.slick.resources,
+Export-Package: net.java.sip.communicator.slick.fileaccess,
diff --git a/test/net/java/sip/communicator/slick/history/history.slick.manifest.mf b/test/net/java/sip/communicator/slick/history/history.slick.manifest.mf
index f77518b..f8757c8 100644
--- a/test/net/java/sip/communicator/slick/history/history.slick.manifest.mf
+++ b/test/net/java/sip/communicator/slick/history/history.slick.manifest.mf
@@ -6,10 +6,8 @@ Bundle-Version: 0.0.1
Import-Package: junit.framework,
net.java.sip.communicator.slick.history,
net.java.sip.communicator.service.history.records,
- net.java.sip.communicator.service.history.query,
net.java.sip.communicator.service.history,
net.java.sip.communicator.service.configuration,
- net.java.sip.communicator.service.protocol,
org.osgi.framework,
org.w3c.dom,
javax.xml.parsers,
diff --git a/test/net/java/sip/communicator/slick/media/media.slick.manifest.mf b/test/net/java/sip/communicator/slick/media/media.slick.manifest.mf
index b7cc1f4..7fa5bc7 100644
--- a/test/net/java/sip/communicator/slick/media/media.slick.manifest.mf
+++ b/test/net/java/sip/communicator/slick/media/media.slick.manifest.mf
@@ -5,10 +5,9 @@ Bundle-Vendor: sip-communicator.org
Bundle-Version: 0.0.1
Import-Package: junit.framework,
org.osgi.framework,
+ net.java.sip.communicator.slick.media,
net.java.sip.communicator.service.media,
net.java.sip.communicator.service.media.event,
- net.java.sip.communicator.service.configuration,
- net.java.sip.communicator.service.configuration.event,
net.java.sip.communicator.util,
javax.media,
javax.media.format,
diff --git a/test/net/java/sip/communicator/slick/resources/ResourcesServicesLick.java b/test/net/java/sip/communicator/slick/fileaccess/FileAccessServiceLick.java
index ffb64c2..684c0b3 100644
--- a/test/net/java/sip/communicator/slick/resources/ResourcesServicesLick.java
+++ b/test/net/java/sip/communicator/slick/fileaccess/FileAccessServiceLick.java
@@ -1,21 +1,21 @@
-package net.java.sip.communicator.slick.resources;
+package net.java.sip.communicator.slick.fileaccess;
import org.osgi.framework.*;
import junit.framework.*;
-import net.java.sip.communicator.service.resources.FileAccessService;
+import net.java.sip.communicator.service.fileaccess.FileAccessService;
import java.util.*;
import net.java.sip.communicator.util.*;
/**
* This class launches the bundle of which test the resources bundle.
* this bundle is a set of (j)unit tests. It should be launched by the
* cruisecontrol module.
*
* @author Alexander Pelov
*/
-public class ResourcesServicesLick
+public class FileAccessServiceLick
extends TestSuite
implements BundleActivator
{
@@ -26,15 +26,15 @@ public class ResourcesServicesLick
public static TestCase tcase = new TestCase(){};
/**
- * Start the Resources Sevice Implementation Compatibility Kit.
+ * Start the File Access Sevice Implementation Compatibility Kit.
*
* @param bundleContext BundleContext
* @throws Exception
*/
public void start(BundleContext bundleContext) throws Exception
{
- ResourcesServicesLick.bc = bundleContext;
- setName("ResourcesServicesLick");
+ FileAccessServiceLick.bc = bundleContext;
+ setName("FileAccessServiceLick");
Hashtable properties = new Hashtable();
properties.put("service.pid", getName());
@@ -54,6 +54,4 @@ public class ResourcesServicesLick
{
}
-
-
}
@@ -1,21 +1,21 @@
import net.java.sip.communicator.util.*;
/**
- * This class launches the bundle of which test the resources bundle.
- * this bundle is a set of (j)unit tests. It should be launched by the
+ * This class launches the bundle which tests the fileaccess bundle.
+ * This bundle is a set of (j)unit tests. It should be launched by the
* cruisecontrol module.
*
diff --git a/test/net/java/sip/communicator/slick/resources/TestFileAccessService.java b/test/net/java/sip/communicator/slick/fileaccess/TestFileAccessService.java
index 73be00d..d8da85a 100644
--- a/test/net/java/sip/communicator/slick/resources/TestFileAccessService.java
+++ b/test/net/java/sip/communicator/slick/fileaccess/TestFileAccessService.java
@@ -1,4 +1,4 @@
-package net.java.sip.communicator.slick.resources;
+package net.java.sip.communicator.slick.fileaccess;
import java.io.File;
import java.io.FileInputStream;
@@ -7,7 +7,7 @@ import java.io.IOException;
import java.util.Random;
import junit.framework.TestCase;
-import net.java.sip.communicator.service.resources.FileAccessService;
+import net.java.sip.communicator.service.fileaccess.FileAccessService;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
@@ -52,7 +52,7 @@ public class TestFileAccessService extends TestCase {
public TestFileAccessService(String name) {
super(name);
- BundleContext context = ResourcesServicesLick.bc;
+ BundleContext context = FileAccessServiceLick.bc;
ServiceReference ref = context.getServiceReference(
FileAccessService.class.getName());
this.fileAccessService = (FileAccessService)context.getService(ref);
@@ -60,7 +60,7 @@ public class TestFileAccessService extends TestCase {
/*
* Test method for 'net.java.sip.communicator.service.resources.FileAccessServiceImpl.getTemporaryFile()'
*/
public void testCreateReadWriteTemporaryFile() {
try {
@@ -76,7 +76,7 @@ public class TestFileAccessService extends TestCase {
}
/*
* Test method for 'net.java.sip.communicator.service.resources.FileAccessServiceImpl.getTemporaryFile()'
*/
public void testCreateTemporaryDirectory() throws Exception {
try {
@@ -87,7 +87,7 @@ public class TestFileAccessService extends TestCase {
}
/*
* Test method for 'net.java.sip.communicator.service.resources.FileAccessServiceImpl.getTemporaryFile()'
*/
public void testCreateReadWriteFileInTemporaryDirectory() throws Exception {
int testFiles = 10;
@@ -60,7 +60,7 @@ public class TestFileAccessService extends TestCase {
/*
- * Test method for 'net.java.sip.communicator.service.resources.FileAccessServiceImpl.getTemporaryFile()'
+ * Test method for 'net.java.sip.communicator.service.fileaccess.FileAccessServiceImpl.getTemporaryFile()'
*/
public void testCreateReadWriteTemporaryFile() {
@@ -76,7 +76,7 @@ public class TestFileAccessService extends TestCase {
}
/*
- * Test method for 'net.java.sip.communicator.service.resources.FileAccessServiceImpl.getTemporaryFile()'
+ * Test method for 'net.java.sip.communicator.service.fileaccess.FileAccessServiceImpl.getTemporaryFile()'
*/
public void testCreateTemporaryDirectory() throws Exception {
@@ -87,7 +87,7 @@ public class TestFileAccessService extends TestCase {
}
/*
- * Test method for 'net.java.sip.communicator.service.resources.FileAccessServiceImpl.getTemporaryFile()'
+ * Test method for 'net.java.sip.communicator.service.fileaccess.FileAccessServiceImpl.getTemporaryFile()'
*/
public void testCreateReadWriteFileInTemporaryDirectory() throws Exception {